==> haskell-apply-refact-0.9.2.0-7-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-apply-refact.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 apply-refact
version:              0.9.2.0
visibility:           public
id:                   apply-refact-0.9.2.0-5GPcRsY97Q71qOZvkGfECs
key:                  apply-refact-0.9.2.0-5GPcRsY97Q71qOZvkGfECs
license:              BSD-3-Clause
maintainer:           matthewtpickering@gmail.com
author:               Matthew Pickering
homepage:             https://github.com/mpickering/apply-refact
synopsis:             Perform refactorings specified by the refact library.
description:
    Perform refactorings specified by the refact library. It is primarily used with HLint'\''s --refactor flag.

category:             Development
abi:                  d87db2071a3e48f2d7348dae9ff69e95
exposed:              True
exposed-modules:
    Refact.Apply Refact.Fixity Refact.Internal Refact.Utils

import-dirs:          /usr/lib/ghc-8.10.4/site-local/apply-refact-0.9.2.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/apply-refact-0.9.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/apply-refact-0.9.2.0
hs-libraries:         HSapply-refact-0.9.2.0-5GPcRsY97Q71qOZvkGfECs
depends:
    base-4.14.1.0 containers-0.6.2.1 directory-1.3.6.0
    extra-1.7.9-FeOLgE4fXkBLbg55bEDq7y
    filemanip-0.3.6.3-CgARrYvUpzx5RyjzD9wl6k ghc-8.10.4
    ghc-boot-th-8.10.4 ghc-exactprint-0.6.4-HxUIfszWIFJEqFaXBYSTd1
    process-1.6.9.0 refact-0.3.0.2-6u7IO6ToowUCnxAhxxe42G
    syb-0.7.2.1-IHzu7I6ikCoGwAbnu6OBXz transformers-0.5.6.2
    uniplate-1.6.13-BFzKLegHfoXIF3WEhacpog
    unix-compat-0.5.3-E98n0JyMac7Bz478oqWJHX

haddock-interfaces:
    /usr/share/doc/haskell-apply-refact/html/apply-refact.haddock

haddock-html:         /usr/share/doc/haskell-apply-refact/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-apply-refact-0.9.2.0-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-apply-refact.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 apply-refact
version:              0.9.2.0
visibility:           public
id:                   apply-refact-0.9.2.0-FXfgxRkwhv86mFPbTHxEX
key:                  apply-refact-0.9.2.0-FXfgxRkwhv86mFPbTHxEX
license:              BSD-3-Clause
maintainer:           matthewtpickering@gmail.com
author:               Matthew Pickering
homepage:             https://github.com/mpickering/apply-refact
synopsis:             Perform refactorings specified by the refact library.
description:
    Perform refactorings specified by the refact library. It is primarily used with HLint'\''s --refactor flag.

category:             Development
abi:                  50c624039fc982db83db1b62809483d9
exposed:              True
exposed-modules:
    Refact.Apply Refact.Fixity Refact.Internal Refact.Utils

import-dirs:          /usr/lib/ghc-8.10.4/site-local/apply-refact-0.9.2.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/apply-refact-0.9.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/apply-refact-0.9.2.0
hs-libraries:         HSapply-refact-0.9.2.0-FXfgxRkwhv86mFPbTHxEX
depends:
    base-4.14.1.0 containers-0.6.2.1 directory-1.3.6.0
    extra-1.7.9-B289Y5Rzkww81ONKh8ABWZ
    filemanip-0.3.6.3-CgARrYvUpzx5RyjzD9wl6k ghc-8.10.4
    ghc-boot-th-8.10.4 ghc-exactprint-0.6.4-3771fRgM43uJAk1Ga8YCrM
    process-1.6.9.0 refact-0.3.0.2-6u7IO6ToowUCnxAhxxe42G
    syb-0.7.2.1-IHzu7I6ikCoGwAbnu6OBXz transformers-0.5.6.2
    uniplate-1.6.13-3uQOf6WYjOWLPIeaKuukpy
    unix-compat-0.5.3-E98n0JyMac7Bz478oqWJHX

haddock-interfaces:
    /usr/share/doc/haskell-apply-refact/html/apply-refact.haddock

haddock-html:         /usr/share/doc/haskell-apply-refact/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
